pub trait WriteCacheUploadStoreWrapper: Send + Sync {
// Required method
fn wrap(&self, store: ObjectStore, op_type: OperationType) -> ObjectStore;
}Expand description
Wraps the remote object store used by write cache uploads.
Required Methods
Sourcefn wrap(&self, store: ObjectStore, op_type: OperationType) -> ObjectStore
fn wrap(&self, store: ObjectStore, op_type: OperationType) -> ObjectStore
Wraps an object store before uploading a cached file.
op_type identifies the origin of the upload so implementations can
apply different policies per operation, e.g. throttling compaction
uploads but not flush uploads. Index rebuild uploads are reported as
OperationType::Compact.